@@ -19,7 +19,7 @@ import os.path
 class EndOfLineComment(str):
     pass
 
-sched_version = "3" # version of SCHED VEX writing routine
+sched_version = "4" # version of SCHED VEX writing routine
 
 block_separator = "*------------------------------------------------------"\
                   "------------------------\n"
@@ -964,7 +964,7 @@ def stations_block(vex_version, print_warnings):
                          "{:6.1f} deg/min".format(station.ax2rate),
                          "{} sec".format(int(station.tsettle))))
             if (station.mount == "ALTAZ") and \
-               station.station.startswith("VLBA"):
+               (station.station[:3] not in {"GBT", "VLA"}):
                 antenna += pointing_sectors(station, vex_version, 
                                             print_warnings)
             
@@ -1282,7 +1282,7 @@ def sched_block(scan_mode, vex_version, print_warnings):
                         media_position = ""
 
                     pointing_sector = ""
-                    if station.station.startswith("VLBA"):
+                    if station.station[:3] not in {"GBT", "VLA"}:
                         zone = scan_sector(
                             station, scan,
                             station.az1[scan_index+scan_offset],
